@@ -254,7 +254,7 @@ def test_cookies(cookies):
     assert any(header == b'cookie' for header, _ in scope['headers'])
 
 
-def test_cookies_options_meathod():
+def test_cookies_options_method():
     scope = testing.create_scope(method='OPTIONS', cookies={'foo': 'bar'})
     assert not any(header == b'cookie' for header, _ in scope['headers'])
 
