@@ -11,10 +11,10 @@ from falcon import testing
 from falcon.media.multipart import MultipartParseOptions
 from falcon.util import BufferedReader
 
-try:
-    import msgpack
-except ImportError:
-    msgpack = None
+
+@pytest.fixture(scope='session')
+def msgpack():
+    return pytest.importorskip('msgpack')
 
 
 EXAMPLE1 = (
@@ -68,19 +68,19 @@ EXAMPLE3 = (
 )
 
 LOREM_IPSUM = (
-    'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod '
-    'tempor incididunt ut labore et dolore magna aliqua. Dolor sed viverra '
-    'ipsum nunc aliquet bibendum enim. In massa tempor nec feugiat. Nunc '
-    'aliquet bibendum enim facilisis gravida. Nisl nunc mi ipsum faucibus '
-    'vitae aliquet nec ullamcorper. Amet luctus venenatis lectus magna '
-    'fringilla. Volutpat maecenas volutpat blandit aliquam etiam erat velit '
-    'scelerisque in. Egestas egestas fringilla phasellus faucibus scelerisque '
-    'eleifend. Sagittis orci a scelerisque purus semper eget duis. Nulla '
-    'pharetra diam sit amet nisl suscipit. Sed adipiscing diam donec '
-    'adipiscing tristique risus nec feugiat in. Fusce ut placerat orci nulla. '
-    'Pharetra vel turpis nunc eget lorem dolor. Tristique senectus et netus '
-    'et malesuada.\n'
-).encode()
+    b'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod '
+    b'tempor incididunt ut labore et dolore magna aliqua. Dolor sed viverra '
+    b'ipsum nunc aliquet bibendum enim. In massa tempor nec feugiat. Nunc '
+    b'aliquet bibendum enim facilisis gravida. Nisl nunc mi ipsum faucibus '
+    b'vitae aliquet nec ullamcorper. Amet luctus venenatis lectus magna '
+    b'fringilla. Volutpat maecenas volutpat blandit aliquam etiam erat velit '
+    b'scelerisque in. Egestas egestas fringilla phasellus faucibus scelerisque '
+    b'eleifend. Sagittis orci a scelerisque purus semper eget duis. Nulla '
+    b'pharetra diam sit amet nisl suscipit. Sed adipiscing diam donec '
+    b'adipiscing tristique risus nec feugiat in. Fusce ut placerat orci nulla. '
+    b'Pharetra vel turpis nunc eget lorem dolor. Tristique senectus et netus '
+    b'et malesuada.\n'
+)
 
 EXAMPLE4 = (
     b'--boundary\r\n'
@@ -210,7 +210,7 @@ def test_invalid_text_or_charset(charset, data):
         b'--BOUNDARY\r\n'
         b'Content-Disposition: form-data; name="text"\r\n'
         b'Content-Type: text/plain; '
-        + 'charset={}\r\n\r\n'.format(charset).encode()
+        + f'charset={charset}\r\n\r\n'.encode()
         + data
         + b'\r\n'
         b'--BOUNDARY\r\n'
@@ -414,7 +414,7 @@ class AsyncMultipartAnalyzer:
 
 
 @pytest.fixture
-def custom_client(asgi, util):
+def custom_client(asgi, util, msgpack):
     def _factory(options):
         multipart_handler = media.MultipartFormHandler()
         for key, value in options.items():
@@ -596,20 +596,19 @@ def test_too_many_body_parts(custom_client, max_body_part_count):
         assert len(resp.json) == EXAMPLE2_PART_COUNT
 
 
-@pytest.mark.skipif(not msgpack, reason='msgpack not installed')
 @pytest.mark.parametrize('close_delimiter', ['--', '--\r\n'])
-def test_random_form(client, close_delimiter):
+def test_random_form(client, close_delimiter, msgpack):
     part_data = [os.urandom(random.randint(0, 2**18)) for _ in range(64)]
     form_data = (
         b''.join(
-            '--{}\r\n'.format(HASH_BOUNDARY).encode()
-            + 'Content-Disposition: form-data; name="p{}"\r\n'.format(i).encode()
+            f'--{HASH_BOUNDARY}\r\n'.encode()
+            + f'Content-Disposition: form-data; name="p{i}"\r\n'.encode()
             + b'Content-Type: application/x-falcon-urandom\r\n\r\n'
             + part_data[i]
             + b'\r\n'
             for i in range(64)
         )
-        + '--{}{}'.format(HASH_BOUNDARY, close_delimiter).encode()
+        + f'--{HASH_BOUNDARY}{close_delimiter}'.encode()
     )
 
     handler = media.MultipartFormHandler()
@@ -786,6 +785,46 @@ def test_filename_star(client):
     }
 
 
+@pytest.mark.parametrize(
+    'max_length,expected',
+    [
+        (None, '__Arrow.txt'),
+        (0, '__Arrow.txt'),
+        (4, '__Ar'),
+        (5, '_.txt'),
+        (7, '__A.txt'),
+        (10, '__Arro.txt'),
+        (64, '__Arrow.txt'),
+    ],
+)
+def test_max_secure_filename_length(custom_client, max_length, expected):
+    client = custom_client({'max_secure_filename_length': max_length})
+
+    data = (
+        b'--a0d738bcdb30449eb0d13f4b72c2897e\r\n'
+        b'Content-Disposition: form-data; name="file"; '
+        b'filename=\xe2\xac\x85 Arrow.txt\r\n\r\n'
+        b'A unicode arrow in the filename.\r\n'
+        b'--a0d738bcdb30449eb0d13f4b72c2897e--\r\n'
+    )
+    content_type = 'multipart/form-data; boundary=' + 'a0d738bcdb30449eb0d13f4b72c2897e'
+
+    resp = client.simulate_post(
+        '/submit', headers={'Content-Type': content_type}, body=data
+    )
+    assert resp.status_code == 200
+    assert resp.json == [
+        {
+            'content_type': 'text/plain',
+            'data': 'A unicode arrow in the filename.',
+            'filename': '⬅ Arrow.txt',
+            'name': 'file',
+            'secure_filename': expected,
+            'text': 'A unicode arrow in the filename.',
+        }
+    ]
+
+
 @pytest.mark.parametrize('max_headers_size', [64, 140, 141, 142, 256, 1024])
 def test_headers_edge_cases(custom_client, max_headers_size):
     client = custom_client({'max_body_part_headers_size': max_headers_size})
@@ -848,13 +887,13 @@ def test_deserialize_custom_media(custom_client):
         def deserialize(self, stream, content_type, content_length):
             first_byte = stream.read(1)
             if first_byte:
-                return '0x{:02x}'.format(first_byte[0])
+                return f'0x{first_byte[0]:02x}'
             return ''
 
         async def deserialize_async(self, stream, content_type, content_length):
             first_byte = await stream.read(1)
             if first_byte:
-                return '0x{:02x}'.format(first_byte[0])
+                return f'0x{first_byte[0]:02x}'
             return ''
 
     handlers = media.Handlers({'application/x-falcon-first-byte': FirstByteHandler()})
